SystemOrganization addCategory: #'Magritte-Tests-Core'!
SystemOrganization addCategory: #'Magritte-Tests-Model'!
SystemOrganization addCategory: #'Magritte-Tests-Description'!
SystemOrganization addCategory: #'Magritte-Tests-Accessor'!
SystemOrganization addCategory: #'Magritte-Tests-Memento'!
SystemOrganization addCategory: #'Magritte-Tests-Relation'!
SystemOrganization addCategory: #'Magritte-Tests-Command'!
SystemOrganization addCategory: #'Magritte-Tests-Utility'!

TestCase subclass: #MAFileModelTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 8/10/2005 19:57'!
testContents
	| model |
	model := MAFileModel new.
	self assert: model contents isEmpty.
	
	model contents: #( 1 2 ).
	self assert: model contents = #( 1 2 ).! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 8/10/2005 19:58'!
testFilename
	| model |
	model := MAFileModel new.
	self assert: model filename isEmpty.
	self assert: model extension isEmpty.
	
	model filename: 'test.txt'.
	self assert: model filename = 'test.txt'.
	self assert: model extension = 'txt'.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 8/10/2005 19:58'!
testMimetype
	| model |
	model := MAFileModel new.
	self assert: model mimetype = 'application/octet-stream'.
	
	model filename: 'test.txt'.
	self assert: model mimetype = 'text/plain'.
	
	model mimetype: 'text/html'.
	self assert: model mimetype = 'text/html'.! !

TestCase subclass: #MATestCase
	instanceVariableNames: 'notifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MATestCase subclass: #MAConventionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MAConventionTests methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:30'!
cleanCategories
	"self new cleanCategories"
	
	self classesDo: [ :class | 
		class organization 
			removeEmptyCategories; 
			sortCategories.
		class class organization 
			removeEmptyCategories; 
			sortCategories ].! !

!MAConventionTests methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:30'!
cleanMethods
	"self new cleanMethods"
	
	| old new |
	self selectorsDo: [ :class :selector |
		old := (class sourceCodeAt: selector)
			asString withBlanksTrimmed readStream.
		new := String streamContents: [ :stream |
			[ old atEnd ] whileFalse: [
				stream nextPutAll: (old upTo: $^ ).
				old atEnd ifFalse: [
					stream nextPutAll: '^ '.
					[ old peek = Character space ]
						whileTrue: [ old next ] ] ] ].
		old = new 
			ifFalse: [ class compile: new ] ].! !

!MAConventionTests methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
decompiledSourceCodeIn: aClass at: aSelector
	| method |
	method := aClass decompile: aSelector.
	method := method decompileString readStream
		nextLine;
		upToEnd.
	^ method withBlanksCondensed.! !

!MAConventionTests methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
originalSourceCodeIn: aClass at: aSelector
	| input output |
	input := (aClass sourceCodeAt: aSelector) readStream
		nextLine;
		yourself.
	output := String streamContents: [ :stream |
		[ input atEnd ] whileFalse: [
			stream nextPutAll: (input upTo: $").
			input atEnd 
				ifFalse: [ input upTo: $" ] ] ].
	^ output withBlanksCondensed.! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testAbstractAndDescription
	"Classes not being tagged as abstract, should return a proper description."
	"self debug: #testAbstractAndDescription"

	self subclassesOf: MAObject do: [ :class |
		class isAbstract ifFalse: [
			self 
				deny: class description isNil 
				description: class name , ' should have a proper description.' 
				resumable: true ] ].! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testAbstractAndResponsability
	"Classes being tagged as concrete, shouldn't call #subclassResponsability."
	"self debug: #testAbstractAndResponsability"

	| method |
	self subclassesOf: MAObject do: [ :class |
		class isAbstract ifFalse: [
			class allSelectors do: [ :selector |
				method := class lookupSelector: selector.
				self 
					deny: (method hasLiteral: #subclassResponsibility)
					description: class name , ' is abstract because of #' , selector 
					resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodArguments
	"For readability we do not want more than 5 arguments a method."
	"self debug: #testMethodArguments"

	self selectorsDo: [ :class :selector |
		 self
			deny: selector numArgs > 5
			description: class name , '>>' , selector , ' has too many arguments.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodCompile
	"All methods should be properly compileable."
	"self debug: #testMethodCompile"
	
	self selectorsDo: [ :class :selector | 
		class recompile: selector ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodCurlyBrace
	"For portability we don't want curly braces in our code."
	"self debug: #testMethodCurlyBrace"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#braceStream: 
				#braceWith: 
				#braceWith:with: 
				#braceWith:with:with: 
				#braceWith:with:with:with: 
				#braceWithNone ))
			description: class name , '>>' , selector , ' contains curly braces.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodFullstop
	"Methods other than simple accessors should all end with a fullstop."
	"self debug: #testMethodFullstop"

	| source |
	self selectorsDo: [ :class :selector |
		source := self originalSourceCodeIn: class at: selector.
		self
			assert: (source lineCount <= 1 or: [ source endsWith: '.' ]) 
			description: class name , '>>' , selector , ' doesn''t end with a fullstop.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodHalt
	"Debugging code needs to be removed before deployment."
	"self debug: #testMethodHalt"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#halt
				#halt: 
				#haltIfNil ))
			description: class name , '>>' , selector , ' has got debugging statements.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodInitialize
	"All instance-side implementors of initialize should call super initialize, class side implementers douldn't call super."
	"self debug: #testMethodInitialize"

	| source |
	self selectorsDo: [ :class :selector |
		selector = #initialize ifTrue: [
			source := self originalSourceCodeIn: class at: selector.
			class isMeta 
				ifTrue: [
					self
						deny: ('*super initialize.*' match: source)
						description: class name , '>>' , selector , ' calls super.'
						resumable: true ]
				ifFalse: [
					self
						assert: ('*super initialize.*' match: source)
						description: class name , '>>' , selector , ' doesn''t call super.'
						resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodMaxLines
	"For readability we do not want methods to be short."
	"self debug: #testMethodMaxLines"

	| source |
	self selectorsDo: [ :class :selector |
		source := self decompiledSourceCodeIn: class at: selector.
		self
			assert: (source lineCount <= 16 
				or: [ source size <= 1024 ] 
				or: [ selector beginsWith: #default ])
			description: class name , '>>' , selector , ' is too long.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodPostCopy
	"All implementors of postCopy should call super postCopy."
	"self debug: #testMethodPostCopy"

	| source |
	self selectorsDo: [ :class :selector |
		source := self originalSourceCodeIn: class at: selector.
		selector = #postCopy ifTrue: [
			self
				assert: ('*super postCopy.*' match: source)
				description: class name , '>>' , selector , ' doesn''t call super.'
				resumable: true ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodReturn
	"There should be a space before any return value."
	"self debug: #testMethodReturn"
	
	| source |
	self selectorsDo: [ :class :selector |
		source := (self originalSourceCodeIn: class at: selector)
			readStream.
		[ source atEnd ] whileFalse: [
			source upTo: $^ .
			source atEnd ifFalse: [
				self
					assert: (source next = Character space)
					description: class name , '>>' , selector , ' doesn''t has a missing space before return.'
					resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodTagged
	"Tagged code is usually a bad sign."
	"self debug: #testMethodTagged"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#flag:
				#shouldBeImplemented ))
			description: class name , '>>' , selector , ' is tagged.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testMethodUnclassified
	"All methods should be classified."
	"self debug: #testMethodUnclassified"
	
	self classesDo: [ :class |
		self
			deny: (class organization categories includes: #'as yet unclassified')
			description: class name , ' has got unclassified method(s).'
			resumable: true ].! !

MATestCase subclass: #MADynamicObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCalculated
	| object dummy |
	object := MADynamicObject on: [ Time millisecondClockValue ].
	dummy := object yourself.
	
	(Delay forMilliseconds: 2) wait.
	self assert: dummy < object.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCollection
	| object |
	object := MADynamicObject on: [ OrderedCollection with: 1 with: 2 ].
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testConstant
	| object |
	object := MADynamicObject on: [ self ].
	self assert: object = self.
	
	object := MADynamicObject on: [ 123 ].
	self assert: object = 123.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testNull
	| object |
	object := MADynamicObject on: 'abc'.
	self deny: object isNil.
	self assert: object notNil.
	
	object := MADynamicObject on: nil.
	self assert: object isNil.
	self deny: object notNil.! !

MATestCase subclass: #MAObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MAObjectTest subclass: #MAAccessorTest
	instanceVariableNames: 'accessor value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
accessor
	^ accessor! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
instance
	^ accessor! !

!MAAccessorTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:29'!
setUp
	super setUp.
	accessor := self accessorInstance.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 7/7/2005 15:39'!
testRead
	self accessor canRead
		ifTrue: [ self error: 'Missing read test.' ].! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 7/7/2005 15:39'!
testWrite
	self accessor canWrite
		ifTrue: [ self error: 'Missing write test.' ].! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAAccessor! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value
	^ value! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value: anObject
	value := anObject! !

MAAccessorTest subclass: #MABlockAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MABlockAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	^ self testedClass
		read: [ :model | model value ]
		write: [ :model :object | model value: object ].! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self assert: self instance canRead.
	self instance readBlock: nil.
	self deny: self instance canRead.! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self assert: self instance canWrite.
	self instance writeBlock: nil.
	self deny: self instance canWrite.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testReadBlock
	self accessor readBlock: [ :model |
		self assert: model = self. 123 ].
	self assert: (self accessor read: self) = 123.! !

!MABlockAccessorTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:29'!
testReferenceStream
	"The class BlockContext is not serializeable, ignore this test."! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWriteBlock
	self accessor writeBlock: [ :model :object |
		self assert: model = self.
		self assert: object = 123 ].
	self accessor write: 123 to: self.! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MABlockAccessor! !

MAAccessorTest subclass: #MACascadeAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACascadeAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	^ self testedClass selectors: #( holder contents value ).! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
holder
	^ ValueHolder new 
		contents: self;
		yourself.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self assert: self accessor canRead.
	self accessor next next readSelector: nil.
	self deny: self accessor canRead.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor next next writeSelector: nil.
	self deny: self accessor canWrite.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testKind
	self assert: (self accessor isKindOf: MACascadeAccessor).
	self assert: (self accessor accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next isKindOf: MACascadeAccessor).
	self assert: (self accessor next accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next next isKindOf: MASelectorAccessor).! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testSelector
	self assert: self accessor accessor selector = #holder.
	self assert: self accessor next accessor selector = #contents.
	self assert: self accessor next next selector = #value.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MACascadeAccessor! !

MAAccessorTest subclass: #MAContainerAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAContainerAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
accessorInstance
	^ self testedClass new.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testCanRead
	self assert: self accessor canRead.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testCanWrite
	self deny: self accessor canWrite.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testRead
	self assert: (self accessor read: 123) = 123.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAContainerAccessor! !

MAAccessorTest subclass: #MANullAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MANullAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
accessorInstance
	^ self testedClass new.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:31'!
testCanRead
	self deny: self accessor canRead.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:31'!
testCanWrite
	self deny: self accessor canWrite.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testRead
	self 
		should: [ self accessor read: self ]
		raise: Error.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MANullAccessor! !

MAAccessorTest subclass: #MASelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

MASelectorAccessorTest subclass: #MAAutoSelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAutoSelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAAutoSelectorAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAAutoSelectorAccessor! !

!MASelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
accessorInstance
	^ self testedClass selector: #value.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:32'!
testCanRead
	self assert: self accessor canRead.
	self accessor readSelector: nil.
	self deny: self accessor canRead.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:32'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor writeSelector: nil.
	self deny: self accessor canWrite.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testReadSelector
	self accessor readSelector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #value:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testSelector
	self accessor selector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWriteSelector
	self accessor writeSelector: #contents:.
	
	self assert: self accessor selector = #value.
	self assert: self accessor readSelector = #value.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASelectorAccessor! !

MAAccessorTest subclass: #MAVariableAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAVariableAccessorTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 5/9/2005 13:48'!
accessorInstance
	^ self testedClass name: 'value'.! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 6/2/2005 10:52'!
testCanRead
	self assert: self accessor canRead.! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 6/2/2005 10:52'!
testCanWrite
	self assert: self accessor canWrite.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:48'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:49'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAVariableAccessor! !

MAObjectTest subclass: #MACommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Command'!

MACommandTest subclass: #MABlockCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Command'!

!MABlockCommandTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MABlockCommandTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MABlockCommand! !

!MACommandTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MACommandTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MACommand! !

MACommandTest subclass: #MASendCommandTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Command'!

!MASendCommandTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MASendCommandTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASendCommand! !

MAObjectTest subclass: #MADescriptionTest
	instanceVariableNames: 'description memento'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MADescriptionTest subclass: #MAContainerTest
	instanceVariableNames: 'child1 child2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAContainerTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
child1
	child1 isNil
		ifTrue: [ child1 := MAStringDescription selector: #child1 label: 'child1' priority: 1 ].
	^ child1.! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 7/7/2005 15:08'!
child2
	child2 isNil
		ifTrue: [ child2 := MAStringDescription selector: #child2 label: 'child2' priority: 2 ].
	^ child2.! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 5/8/2005 20:30'!
testAdd
	self description add: self child1.
	self assert: (self description size = 1).
	self assert: (self description includes: self child1).
	
	self description add: self child2.
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 5/8/2005 20:30'!
testAddAll
	self description addAll: (Array 
		with: self child1 
		with: self child2).
	
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self assert: self description asContainer = self description.
	self assert: self description asContainer == self description.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testChildren
	self assert: self description children isCollection.
	self assert: self description children isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:08'!
testCollect
	| collected |
	self description add: self child1; add: self child2.
	collected := self description collect: [ :each | each ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | each copy ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | 
		each copy
			accessor: (MASelectorAccessor selector: #foo);
			yourself ].
	self deny: self description = collected.
	self deny: self description == collected.


! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:30'!
testConcatenation
	| concatenate |
	concatenate := self description , self child1.
	self assert: concatenate size = 1.
	self assert: concatenate children first = self child1.
	
	concatenate := concatenate , self child2 asContainer.
	self assert: concatenate size = 2.
	self assert: concatenate children first = self child1.
	self assert: concatenate children second = self child2.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopy
	self description add: self child1; add: self child2.
	super testCopy.
	
	self deny: self description copy children == self description children.
	self assert: self description copy children first = self description children first.
	self assert: self description copy children second = self description children second.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopyFromTo
	| copied |
	self description add: self child1; add: self child2.
	copied := self description copyFrom: 1 to: 1.
	
	self assert: copied ~= self description.
	self assert: copied size = 1.
	self assert: copied children first = self description children first.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetect
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ]) = self child1.
	self should: [ self description 
		detect: [ :each | self child2 = each ] ] raise: Error.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetectIfNone
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ] 
		ifNone: [ 123 ]) = self child1.
	self assert: (self description 
		detect: [ :each | self child2 = each ] 
		ifNone: [ 123 ]) = 123.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDo
	| collection |
	collection := self description class defaultCollection.
	self description add: self child1; add: self child2.
	self description do: [ :each | collection add: each ].
	self assert: (self description children hasEqualElements: collection).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDoSepratedBy
	| collection |
	collection := OrderedCollection new.
	self description add: self child1; add: self child2.
	self description 
		do: [ :each | collection add: each ]
		separatedBy: [ collection add: nil ].
	self assert: collection size = 3.
	self assert: collection first = self child1.
	self assert: collection second isNil.
	self assert: collection third = self child2.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testEmpty
	self assert: self description isEmpty.
	self description add: self child1.
	self deny: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	super testHasChildren.
	self description add: self child1.
	self assert: self description hasChildren.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIncludes
	self deny: (self description includes: self child1).
	self description add: self child1.
	self assert: (self description includes: self child1).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testInjectInto
	self description add: self child1; add: self child2.
	self assert: (self description 
		inject: 'start'
		into: [ :result :each | result , ' ' , each label ]) = 'start child1 child2'.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self assert: self description isContainer.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:30'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveDown: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	
	self description moveDown: self child1.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:30'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveUp: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	
	self description moveUp: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testNotEmpty
	self deny: self description notEmpty.
	self description add: self child1.
	self assert: self description notEmpty.! !

!MAContainerTest methodsFor: 'testing-indentity' stamp: 'lr 5/8/2005 20:30'!
testReferenceStream
	" self debug: #testReferenceStream "
	
	| object |
	self description add: self child1; add: self child2.
	object := super testReferenceStream.
	
	self assert: object children first = self child1.
	self deny: object children first == self child1.
	
	self assert: object children second = self child2.
	self deny: object children second == self child2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:14'!
testReject
	| rejected |
	self description add: self child1; add: self child2.
	
	rejected := self description reject: [ :each | false ].
	self assert: self description = rejected.

	rejected := self description reject: [ :each | true ].
	self assert: rejected isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemove
	self description add: self child1; add: self child2.

	self description remove: self child1.
	self assert: self description size = 1.
	self deny: (self description includes: self child1).
	self assert: (self description includes: self child2).

	self description remove: self child2.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemoveAll
	self description add: self child1; add: self child2.

	self description removeAll.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:15'!
testSelect
	| selected |
	self description add: self child1; add: self child2.
	
	selected := self description select: [ :each | true ].
	self assert: self description = selected.
	
	selected := self description select: [ :each | false ].
	self assert: selected isEmpty.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testSize
	self assert: self description size isZero.
	self description add: self child1.
	self assert: self description size = 1.
	self description add: self child2.
	self assert: self description size = 2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:37'!
testWithDo
	self description add: self child1; add: self child2.
	self description with: self description children do: [ :first :second |
		self assert: first = second ].! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testWithIndexDo
	self description add: self child1; add: self child2.
	self description withIndexDo: [ :each :index | 
		index = 1
			ifTrue: [ self assert: self child1 = each ]
			ifFalse: [
				index = 2
					ifTrue: [ self assert: self child2 = each ]
					ifFalse: [ self assert: false ] ] ].! !

!MAContainerTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAContainer! !

MAContainerTest subclass: #MAPriorityContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPriorityContainerTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:31'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child2 priority = 2.
	
	self description moveDown: self child2; moveDown: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child2 priority = 0.! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:31'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child1 priority = 1.
	
	self description moveUp: self child1; moveUp: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child1 priority = 3.! !

!MAPriorityContainerTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAPriorityContainer! !

MAContainerTest subclass: #MAReportContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAReportContainerTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAReportContainerTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAReportContainer! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 5/8/2005 20:33'!
shouldInheritSelectors
	^ true! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
description
	^ description! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
descriptionInstance
	^ self testedClass new.! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
instance
	^ description! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:50'!
memento
	^ memento! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
mementoInstance
	^ MAStraitMemento on: self description model: self.! !

!MADescriptionTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:30'!
setUp
	super setUp.
	description := self descriptionInstance.
	memento := self mementoInstance.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self subclassResponsibility.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsLabel
	self assert: self description asLabel = self description asString.
	
	self description label: 'foo'.
	self assert: self description asLabel = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testComment
	self description comment: 'bar'.
	self assert: self description comment = 'bar'.! !

!MADescriptionTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopy
	self deny: self description == self description copy.
	self deny: self description properties == self description copy properties.
	
	self assert: self description properties = self description copy properties.
	self assert: self description properties size = self description copy properties size.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testDictionaryKey
	| dictionary |
	dictionary := Dictionary new.
	
	dictionary at: self instance put: 1.
	self assert: (dictionary at: self instance) = 1.
	
	dictionary at: self instance put: 2.
	self assert: (dictionary at: self instance) = 2.! !

!MADescriptionTest methodsFor: 'testing-comparing' stamp: 'lr 5/8/2005 20:30'!
testEqual
	self assert: self instance = self instance.
	self assert: self instance = self instance copy.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	self deny: self description hasChildren.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasComment
	self description comment: nil.
	self deny: self description hasComment.
	
	self description comment: ''.
	self deny: self description hasComment.
	
	self description comment: 'comment'.
	self assert:  self description hasComment.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasLabel
	self description label: nil.
	self deny: self description hasLabel.
	
	self description label: ''.
	self deny: self description hasLabel.
	
	self description label: 'label'.
	self assert:  self description hasLabel.! !

!MADescriptionTest methodsFor: 'testing-comparing' stamp: 'lr 5/8/2005 20:30'!
testHash
	self assert: self instance hash isInteger.
	self assert: self instance hash = self instance hash.
	self assert: self instance hash = self instance copy hash.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self deny: self description isContainer.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testLabel
	self description label: 'foo'.
	self assert: self description label = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testPersistent
	self description beEphemeral.
	self deny: self description persistent.
	self deny: self description isPersistent.
	
	self description bePersistent.
	self assert: self description persistent.
	self assert: self description isPersistent.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testPriority
	self description priority: 123.
	self assert: self description priority = 123.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testReadonly
	self description beReadonly.
	self assert: self description readonly.
	self assert: self description isReadonly.
	
	self description beWriteable.
	self deny: self description readonly.
	self deny: self description isReadonly.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testRequired
	self description beRequired.
	self assert: self description required.
	self assert: self description isRequired.
	
	self description beOptional.
	self deny: self description required.
	self deny: self description isRequired.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testSetElement
	| set |
	set := Set new.
	
	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).

	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testVisible
	self description beHidden.
	self deny: self description visible.
	self deny: self description isVisible.
	
	self description beVisible.
	self assert: self description visible.
	self assert: self description isVisible.! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MADescription! !

MADescriptionTest subclass: #MAElementDescriptionTest
	instanceVariableNames: 'value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAElementDescriptionTest subclass: #MABooleanDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MABooleanDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
includedInstance
	^ true! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MABooleanDescription! !

MAElementDescriptionTest subclass: #MAColorDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAColorDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 7/7/2005 15:44'!
includedInstance
	^ Color blue.! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAColorDescription! !

!MAElementDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
descriptionInstance
	^ self testedClass selector: #value.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
emptyInstance
	^ String new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
includedInstance
	self subclassResponsibility! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ Object new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
nullInstance
	^ nil! !

!MAElementDescriptionTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:31'!
setUp
	super setUp.
	value := self valueInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testAccessor
	self assert: self description accessor selector = #value.! !

!MAElementDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:31'!
testAsContainer
	self assert: (self description asContainer size) = 1.
	self assert: (self description asContainer includes: self description).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:31'!
testConcatenation
	| child1 child2 concatenate |
	child1 := self description copy.
	child2 := self description copy.
	
	concatenate := child1 , child2.
	self assert: concatenate size = 2.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child2.
	
	concatenate := child1 , concatenate.
	self assert: concatenate size = 3.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child1.
	self assert: concatenate children third = child2.! !

!MAElementDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:31'!
testCopy
	super testCopy.
	self deny: self description copy accessor == self description accessor.
	self assert: self description copy default = self description default.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testDefault
	self description default: self includedInstance.
	self assert: self description default = self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testKind
	self assert: (self includedInstance isKindOf: self description kind).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:31'!
testParseString
	self assert: (self description parseString: self nullInstance) isNil.
	self assert: (self description parseString: self emptyInstance) isNil.
	self assert: (self description isSatisfiedBy: (self description 
		parseString: (self description toString: self includedInstance))).! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 5/8/2005 20:38'!
testRead
	| other |
	self value: (other := self includedInstance).
	self assert: self memento value = other.
	
	self value: (other := self nullInstance).
	self assert: self memento value = self description class defaultDefault.! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:31'!
testSatisfied
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self invalidInstance).
	self deny: (self description isSatisfiedBy: self nullInstance).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:31'!
testToString
	self assert: (self description toString: self includedInstance) = self includedInstance asLabel.
	self assert: (self description toString: self nullInstance) = String new.! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:38'!
testValidates
	self shouldnt: [ self memento validate: self includedInstance ] raise: MAError.
	self shouldnt: [ self memento validate: self nullInstance ] raise: MAError.
	self should: [ self memento validate: self invalidInstance ] raise: MAError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 5/8/2005 20:38'!
testWrite
	| other |
	self memento value: (other := self includedInstance).
	self assert: self value = other.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 5/8/2005 20:38'!
testWriteIncluded
	self memento value: self invalidInstance.
	self
		should: [ self memento validate; commit  ]
		raise: MAValidationError.
		
	self memento value: self nullInstance.
	self
		shouldnt: [ self memento validate; commit ]
		raise: MAValidationError.
	
	self memento value: self includedInstance.
	self
		shouldnt: [ self memento validate; commit ]
		raise: MAValidationError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 5/8/2005 20:39'!
testWriteReadonly
	self value: self includedInstance.
	self description beReadonly.
	self
		shouldnt: [ self memento commit ]
		raise: MAReadonlyError.

	self value: self includedInstance.
	self description beWriteable.
	self
		shouldnt: [ self memento commit ]
		raise: MAReadonlyError.! !

!MAElementDescriptionTest methodsFor: 'testing-model' stamp: 'lr 5/8/2005 20:39'!
testWriteRequired
	self description beRequired.
	self value: self nullInstance.
	self
		should: [ self memento validate; commit ]
		raise: MARequiredError.
	self value: self includedInstance.
	self
		shouldnt: [ self memento validate; commit ]
		raise: MARequiredError.
		
	self description beOptional.
	self value: self nullInstance.
	self
		shouldnt: [ self memento validate; commit ]
		raise: MARequiredError.
	self value: self includedInstance.
	self
		shouldnt: [ self memento validate; commit ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAElementDescription! !

!MAElementDescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
value
	^ value! !

!MAElementDescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
value: anObject
	value := anObject! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
valueInstance
	^ nil! !

MAElementDescriptionTest subclass: #MAFileDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAFileDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 8/10/2005 19:54'!
includedInstance
	^ MAFileModel new
		contents: 'Lukas Renggli';
		filename: 'author.txt';
		yourself.! !

!MAFileDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 8/10/2005 20:00'!
testParseString! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAFileDescription! !

MAElementDescriptionTest subclass: #MAMagnitudeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAMagnitudeDescriptionTest subclass: #MADateDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADateDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Date newDay: 11 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:32'!
includedInstanceLower
	^ Date newDay: 10 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:32'!
includedInstanceUpper
	^ Date newDay: 12 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MADateDescription! !

MAMagnitudeDescriptionTest subclass: #MADurationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADurationDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Duration days: 1 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:33'!
includedInstanceLower
	^ Duration days: 0 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:33'!
includedInstanceUpper
	^ Duration days: 2 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MADurationDescription! !

!MAMagnitudeDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:32'!
includedInstanceLower
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:32'!
includedInstanceUpper
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 8/25/2005 10:39'!
testInfToInf
	self assert: self description lowerBounds isNil.
	self assert: self description upperBounds isNil.
	
	self assert: (self description isSatisfiedBy: self includedInstanceLower).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self includedInstanceUpper).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 8/25/2005 11:17'!
testInfToVal
	self description upperBounds: self includedInstance.

	self assert: self description lowerBounds isNil.
	self assert: self description upperBounds = self includedInstance.
	
	self assert: (self description isSatisfiedBy: self includedInstanceLower).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self includedInstanceUpper).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 8/25/2005 11:17'!
testValToInf
	self description lowerBounds: self includedInstance.

	self assert: self description lowerBounds = self includedInstance.
	self assert: self description upperBounds isNil.
	
	self deny: (self description isSatisfiedBy: self includedInstanceLower).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self includedInstanceUpper).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 8/25/2005 10:40'!
testValToVal
	self description lowerBounds: self includedInstance.
	self description upperBounds: self includedInstance.

	self assert: self description lowerBounds = self includedInstance.
	self assert: self description upperBounds = self includedInstance.
	
	self deny: (self description isSatisfiedBy: self includedInstanceLower).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self includedInstanceUpper).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAMagnitudeDescription! !

MAMagnitudeDescriptionTest subclass: #MANumberDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MANumberDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:35'!
includedInstance
	^ 2.7182! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:35'!
includedInstanceLower
	^ 1.6180! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:35'!
includedInstanceUpper
	^ 3.1415! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MANumberDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:33'!
includedInstance
	^ Time hour: 11 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstanceLower
	^ Time hour: 10 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstanceUpper
	^ Time hour: 12 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MATimeDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeStampDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeStampDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstance
	^ TimeStamp year: 1980 month: 6 day: 11 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstanceLower
	^ TimeStamp year: 1980 month: 6 day: 10 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstanceUpper
	^ TimeStamp year: 1980 month: 6 day: 12 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MATimeStampDescription! !

MAElementDescriptionTest subclass: #MASelectionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MASelectionDescriptionTest subclass: #MAMultipleSelectionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAMultipleSelectionDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAMultipleSelectionDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
includedInstance
	^ OrderedCollection 
		with: self optionsInstance last
		with: self optionsInstance first.! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testAdding
	| collection |
	collection := self optionsInstance.
	self description add: nil to: collection.
	self assert: collection = self optionsInstance.
	
	self description beMultiple.
	collection := self optionsInstance.
	self description add: self optionsInstance first to: collection.
	self assert: (collection occurrencesOf: self optionsInstance first) = 2.

	self description beUnique.
	collection := self optionsInstance.
	self description add: self optionsInstance last to: collection.
	self assert: (collection occurrencesOf: self optionsInstance first) = 1.! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testAvailableLabel
	self description availableLabel: 'avail'.
	self assert: self description availableLabel = 'avail'.! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testOrdered
	self description beOrdered.
	self assert: self description isOrdered.
	
	self description beUnordered.
	self deny: self description isOrdered.! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:31'!
testParseString
	" not much sense in this "! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testRemoving
	| collection |
	collection := self optionsInstance.
	self description remove: nil from: collection.
	self assert: collection = self optionsInstance.
	
	collection := self optionsInstance.
	self description remove: self optionsInstance first from: collection.
	self deny: (collection includes: self optionsInstance first).! !

!MAMultipleSelectionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testSelectedLabel
	self description selectedLabel: 'selec'.
	self assert: self description selectedLabel = 'selec'.! !

!MAMultipleSelectionDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAMultipleSelectionDescription! !

!MASelectionDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MASelectionDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
optionsInstance
	^ OrderedCollection with: 'c' with: 'b' with: 'a'.! !

!MASelectionDescriptionTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:32'!
setUp
	super setUp.
	self description options: self optionsInstance.! !

!MASelectionDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:32'!
testCopy
	| copy |
	super testCopy.
	copy := self description copy.
	self deny: copy options == self description options.
	self assert: copy options = self description options.! !

!MASelectionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:32'!
testOptions
	self description options: #( a b c ).
	self assert: self description options = #( a b c ).! !

!MASelectionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:32'!
testOptionsTextual
	self description options: #( 'a' 'b' ).
	self assert: self description optionsTextual = 'a
b'.

	self description optionsTextual: 'x
y'.
	self assert: self description options asArray = #( 'x' 'y' ).! !

!MASelectionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:32'!
testSorted
	self description beSorted; beRequired.
	self assert: self description isSorted.
	self assert: self description allOptions = self optionsInstance asSortedCollection asArray.
	
	self description beUnsorted.
	self deny: self description isSorted.
	self assert: self description allOptions = self optionsInstance asArray.! !

!MASelectionDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASelectionDescription! !

MASelectionDescriptionTest subclass: #MASingleSelectionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASingleSelectionDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MASingleSelectionDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ self optionsInstance last.! !

!MASingleSelectionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:32'!
testNilLabel
	self description nilLabel: 'none'.
	self assert: self description nilLabel = 'none'.! !

!MASingleSelectionDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASingleSelectionDescription! !

MAElementDescriptionTest subclass: #MAStringDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAStringDescriptionTest subclass: #MAPasswordDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPasswordDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAPasswordDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAPasswordDescription! !

!MAStringDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ 'Lukas Renggli'! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAStringDescription! !

MAStringDescriptionTest subclass: #MASymbolDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASymbolDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ #magritte! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASymbolDescription! !

MAStringDescriptionTest subclass: #MATextDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATextDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MATextDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MATextDescription! !

MAElementDescriptionTest subclass: #MATableDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATableDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:33'!
includedInstance
	^ #( 'a1' 'a2' 'b1' 'b2' 'c1' 'c2' )! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:33'!
invalidInstance
	^ #( 'a' 'b' 'c' 'd' 'e' )! !

!MATableDescriptionTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:33'!
setUp
	super setUp.
	self description 
		columnLabels: #( a b );
		rowLabels: #( x y z ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testCellCount
	self assert: self description cellCount = 6.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testCellDescription
	| other |
	self description cellDescription: (other := MANumberDescription new).
	self assert: self description cellDescription = other.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testColumnCount
	self assert: self description columnCount = 2.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:32'!
testColumnLabels
	self description columnLabels: #( '1' '2' ).
	self assert: self description columnLabels = #( '1' '2' ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:32'!
testColumnLabelsTextual
	self description columnLabels: #( '1' '2' ).
	self assert: self description columnLabelsTextual = '1
2'.

	self description columnLabelsTextual: '2
1'.
	self assert: self description columnLabels asArray = #( '2' '1' ).! !

!MATableDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:32'!
testCopy
	| copy |
	super testCopy.
	copy := self description copy.
	self deny: copy rowLabels == self description rowLabels.
	self assert: copy rowLabels = self description rowLabels.
	self deny: copy columnLabels == self description columnLabels.
	self assert: copy columnLabels = self description columnLabels.
	self deny: copy cellDescription == self description cellDescription.! !

!MATableDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:32'!
testParseString! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testRowCount
	self assert: self description rowCount = 3.! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testRowLabels
	self description rowLabels: #( '1' '2' ).
	self assert: self description rowLabels = #( '1' '2' ).! !

!MATableDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:33'!
testRowLabelsTextual
	self description rowLabels: #( '1' '2' ).
	self assert: self description rowLabelsTextual = '1
2'.

	self description rowLabelsTextual: '2
1'.
	self assert: self description rowLabels asArray = #( '2' '1' ).! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MATableDescription! !

MAElementDescriptionTest subclass: #MATokenDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATokenDescriptionTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 11:51'!
includedInstance
	^ #( #foo #bar )! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MATokenDescription! !

MAObjectTest subclass: #MAMementoTest
	instanceVariableNames: 'description memento value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

MAMementoTest subclass: #MACachedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACachedMementoTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testCommit
	self memento value: self includedInstance.
	self assert: self memento hasChanged.
	
	self memento commit.
	self assert: self memento value = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testDefault
	self value: nil.
	self description default: self defaultInstance. 
	
	self memento reset.
	self assert: self memento value = self defaultInstance.
	self assert: self value isNil.
	
	self memento commit.
	self assert: self memento value = self defaultInstance.
	self assert: self value = self defaultInstance.
	
	self memento value: self includedInstance; commit.
	self assert: self memento value = self includedInstance.
	self assert: self value = self includedInstance.! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testInterrupt
	self memento value: self includedInstance.
	[ self memento commit ]
		on: MACommitNotification
		do: [ :ntf | self assert: ntf isBefore ].
	self assert: self value = nil.
	
	self memento value: self includedInstance.
	[ self memento commit ]
		on: MACommitNotification
		do: [ :ntf | 
			ntf isBefore 
				ifTrue: [ ntf resume ] ].
	self assert: self value = self includedInstance.! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self assert: self value = self nullInstance.
	self assert: self memento value = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self value = self includedInstance.
	self assert: self memento value = self defaultInstance.! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testReset
	self value: self defaultInstance.
	self memento value: self includedInstance.
	self assert: self memento hasChanged.
	
	self memento reset.
	self assert: self memento value = self defaultInstance.
	self assert: self value = self defaultInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self value: self defaultInstance.
	self memento value: self includedInstance.
	self assert: self value = self defaultInstance.
	self assert: self memento value = self includedInstance.! !

!MACachedMementoTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MACachedMemento! !

MACachedMementoTest subclass: #MACheckedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACheckedMementoTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MACheckedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testConflictCommit
	self value: self defaultInstance.
	self assert: self memento original = self nullInstance.
	self deny: self memento hasConflict.
	
	self value: self includedInstance.
	self assert: self memento original = self nullInstance.
	self assert: self memento hasConflict.
	
	self memento commit.
	self assert: self memento original = self defaultInstance.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testConflictDefault
	self memento value: self includedInstance.
	self assert: self memento original = self nullInstance.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testConflictMerged
	self value: self includedInstance.
	self memento value: self includedInstance.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MACheckedMemento! !

!MAMementoTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAMementoTest methodsFor: 'comparing' stamp: 'lr 7/7/2005 15:29'!
= anObject
	"To make #testReferenceStream run."

	^ self species = anObject species.! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
accessor
	^ self description accessor.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
accessorInstance
	^ MASelectorAccessor selector: #value.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
defaultInstance
	^ 'Lukas Renggli'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
description
	^ description! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
descriptionInstance
	^ MAStringDescription new
		default: self defaultInstance;
		accessor: self accessorInstance;
		yourself.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
includedInstance
	^ 'Magritte'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ 31415! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
memento
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
mementoInstance
	^ self testedClass on: self description model: self.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
nullInstance
	^ nil! !

!MAMementoTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:31'!
setUp
	super setUp.
	description := self descriptionInstance.
	memento := self mementoInstance.! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testAccessor
	self assert: self memento accessor = self accessor.! !

!MAMementoTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:31'!
testCopy
	super testCopy.
	self assert: self memento copy description isNil.! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testDefault
	self assert: self memento value = self defaultInstance.! !

!MAMementoTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:32'!
testDescription
	self assert: self memento description = self description.! !

!MAMementoTest methodsFor: 'testing-errors' stamp: 'lr 5/8/2005 20:31'!
testErrorConcurrent
	self 
		should: [ self memento errorConcurrent ]
		raise: MAConcurrentError.
	[ self memento errorConcurrent ]
		on: MAConcurrentError
		do: [ :error |
			self assert: error accessor = self accessor.
			self assert: error memento = self memento.
			self assert: error description = self description ].! !

!MAMementoTest methodsFor: 'testing-errors' stamp: 'lr 5/8/2005 20:31'!
testErrorReadonly
	self 
		should: [ self memento errorReadonly ]
		raise: MAReadonlyError.
	[ self memento errorReadonly ]
		on: MAReadonlyError
		do: [ :error |
			self assert: error accessor = self accessor.
			self assert: error memento = self memento.
			self assert: error description = self description ].! !

!MAMementoTest methodsFor: 'testing-errors' stamp: 'lr 5/8/2005 20:31'!
testErrorRequired
	self 
		should: [ self memento errorRequired ]
		raise: MARequiredError.
	[ self memento errorRequired ]
		on: MARequiredError
		do: [ :error | 
			self assert: error accessor = self accessor.
			self assert: error memento = self memento.
			self assert: error description = self description ].! !

!MAMementoTest methodsFor: 'testing-errors' stamp: 'lr 5/8/2005 20:31'!
testErrorValidation
	self 
		should: [ self memento errorValidation ]
		raise: MAValidationError.
	[ self memento errorValidation ]
		on: MAValidationError
		do: [ :error |			
			self assert: error accessor = self accessor.
			self assert: error memento = self memento.
			self assert: error description = self description ].! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testModel
	self assert: self memento model = self.! !

!MAMementoTest methodsFor: 'testing-notifications' stamp: 'lr 5/8/2005 20:31'!
testNotifyCommit
	self memento value: self includedInstance; commit.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first memento = self memento.
	self assert: self notifications first description = self description.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second memento = self memento.
	self assert: self notifications second description = self description.! !

!MAMementoTest methodsFor: 'testing-notifications' stamp: 'lr 5/8/2005 20:31'!
testNotifyReset
	self memento value: self includedInstance; reset.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first memento = self memento.
	self assert: self notifications first description = self description.
	self assert: self notifications first class = MAResetNotification.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second memento = self memento.
	self assert: self notifications second description = self description.
	self assert: self notifications second class = MAResetNotification.! !

!MAMementoTest methodsFor: 'testing-notifications' stamp: 'lr 5/8/2005 20:31'!
testNotifyValidate
	self memento value: self includedInstance; commit.
	
	self assert: self notifications size = 2.
	
	self assert: self notifications first isBefore.
	self assert: self notifications first accessor = self accessor.
	self assert: self notifications first memento = self memento.
	self assert: self notifications first description = self description.
	self assert: self notifications first class = MACommitNotification.
	
	self assert: self notifications second isAfter.
	self assert: self notifications second accessor = self accessor.
	self assert: self notifications second memento = self memento.
	self assert: self notifications second description = self description.
	self assert: self notifications second class = MACommitNotification.! !

!MAMementoTest methodsFor: 'testing-primitives' stamp: 'lr 5/8/2005 20:31'!
testPull
	self value: self nullInstance.
	self assert: self memento pull = self nullInstance.
	
	self value: self invalidInstance.
	self assert: self memento pull = self invalidInstance.
	
	self value: self includedInstance.
	self assert: self memento pull = self includedInstance.! !

!MAMementoTest methodsFor: 'testing-primitives' stamp: 'lr 5/8/2005 20:31'!
testPush
	self memento push: self nullInstance.
	self assert: self value = self nullInstance.
	
	self memento push: self invalidInstance.
	self assert: self value = self invalidInstance.
	
	self memento push: self includedInstance.
	self assert: self value = self includedInstance.! !

!MAMementoTest methodsFor: 'testing-validation' stamp: 'lr 5/8/2005 20:31'!
testValidateIncluded
	self memento value: self invalidInstance.
	self should: [ self memento validate ] raise: MAValidationError.
	
	self memento value: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MARequiredError.! !

!MAMementoTest methodsFor: 'testing-validation' stamp: 'lr 5/8/2005 20:31'!
testValidateReadonly
	self description beReadonly; beRequired.
	
	self memento value: self nullInstance.
	self shouldnt: [ self memento validate ] raise: MAReadonlyError.
	
	self memento value: self invalidInstance.
	self shouldnt: [ self memento validate ] raise: MAReadonlyError.! !

!MAMementoTest methodsFor: 'testing-validation' stamp: 'lr 5/8/2005 20:31'!
testValidateRequired
	self description beRequired.
	self memento value: self nullInstance.
	self should: [ self memento validate ] raise: MARequiredError.
	
	self description beOptional.
	self memento value: self nullInstance.
	self shouldnt: [ self memento validate ] raise: MARequiredError.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAMemento! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value
	^ value! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value: anObject
	value := anObject! !

MAMementoTest subclass: #MAStraitMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MAStraitMementoTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAStraitMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testRead
	self assert: self memento value = self defaultInstance.
	
	self value: '123'.
	self assert: self memento value = '123'.
	
	self value: '321'.
	self assert: self memento value = '321'.! !

!MAStraitMementoTest methodsFor: 'testing-validation' stamp: 'lr 5/8/2005 20:32'!
testValidateRequired
	self description beRequired.
	self memento value: self nullInstance.
	self shouldnt: [ self memento validate ] raise: MARequiredError.
	
	self description beOptional.
	self memento value: self nullInstance.
	self shouldnt: [ self memento validate ] raise: MARequiredError.! !

!MAStraitMementoTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWrite
	self memento value: '123'.
	self assert: self value = '123'.
	
	self memento value: '123'.
	self assert: self value = '123'.! !

!MAStraitMementoTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAStraitMemento! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAObjectTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	self subclassResponsibility.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 7/7/2005 14:48'!
testCopy
	self assert: self instance = self instance.
	self assert: self instance = self instance copy.
	
	self assert: self instance == self instance.
	self deny: self instance == self instance copy.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 7/7/2005 14:39'!
testProperties
	self assert: self instance properties notNil.
	self instance instVarNamed: 'properties' put: nil.
	
	self instance propertyAt: #foo put: #bar.
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsent: [ nil ].
	self instance instVarNamed: 'properties' put: nil.
	
	self instance hasProperty: #foo.
	self instance instVarNamed: 'properties' put: nil.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAt
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	self should: [ self instance propertyAt: #bar ] raise: Error.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsent
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsent: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #bar ifAbsent: [ 'baz' ]) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsentPut
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsentPut: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self assert: (self instance propertyAt: #bar ifAbsentPut: [ 'baz' ]) = 'baz'.
	self assert: (self instance propertyAt: #bar) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtPut
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self instance propertyAt: #foo put: 'baz'.
	self assert: (self instance propertyAt: #foo) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 7/7/2005 14:50'!
testPropertiesHas
	self deny: (self instance hasProperty: #foo).
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance hasProperty: #foo).
	self deny: (self instance hasProperty: #bar).! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:31'!
testReferenceStream
	| output input object |
	
	" every instance should be serializeable "
	output := ReferenceStream on: (RWBinaryOrTextStream on: ByteArray new).
	output nextPut: self instance.
	output close.
	
	" read back the serialized instance "
	input := ReferenceStream on: output contents readStream.
	object := input next.
	
	" different object reference, but equal object "
	self deny: self instance == object.
	self assert: self instance = object.
	
	" return the read in object (for subclasses) "
	^ object.! !

!MAObjectTest methodsFor: 'testing' stamp: 'lr 7/7/2005 14:46'!
testSanity
	"If this test case fails, there is something wrong with the setup of the test-case."
	
	self
		assert: self testedClass isAbstract not
		description: 'Unable to test abstract class.'.
	self 
		assert: self instance class = self testedClass 
		description: 'Invalid test instance.'.
	! !

!MAObjectTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAObject! !

MAObjectTest subclass: #MARelationTest
	instanceVariableNames: 'relation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MARelationTest subclass: #MABasicRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MABasicRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MABasicRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MABasicRelation! !

MABasicRelationTest subclass: #MAConstantRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAConstantRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAConstantRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testFailsFalse
	self fails: self false.! !

!MAConstantRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testSatisfiesTrue
	self satisfies: self true.! !

!MAConstantRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAConstantRelation! !

MABasicRelationTest subclass: #MASelectorRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MASelectorRelationTest subclass: #MAAccessorRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAccessorRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAAccessorRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAAccessorRelation! !

MASelectorRelationTest subclass: #MAQueryRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAQueryRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAQueryRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAQueryRelation! !

!MASelectorRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MASelectorRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MASelectorRelation! !

MARelationTest subclass: #MAComposedRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MAComposedRelationTest subclass: #MAAllRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAllRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testNone
	self satisfies: self relation.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testOne
	self satisfies: self relation & self true.
	self fails: self relation & self false.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testTwo
	self satisfies: self true & self true.
	self fails: self true & self false.
	self fails: self false & self true.
	self fails: self false & self false.! !

!MAAllRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAAllRelation! !

MAComposedRelationTest subclass: #MAAnyRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAnyRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testNone
	self fails: self relation.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testOne
	self satisfies: self relation | self true.
	self fails: self relation | self false.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testTwo
	self satisfies: self true | self true.
	self satisfies: self true | self false.
	self satisfies: self false | self true.
	self fails: self false | self false.! !

!MAAnyRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAAnyRelation! !

!MAComposedRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MAComposedRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MAComposedRelation! !

MAComposedRelationTest subclass: #MANoneRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MANoneRelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ false! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testNone
	self satisfies: self relation.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testOne
	self fails: self relation !! self true.
	self satisfies: self relation !! self false.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testTwo
	self fails: self true !! self true.
	self fails: self true !! self false.
	self fails: self false !! self true.
	self satisfies: self false !! self false.! !

!MANoneRelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MANoneRelation! !

!MARelationTest class methodsFor: 'testing' stamp: 'lr 8/13/2005 11:55'!
isAbstract
	^ true! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:31'!
fails: aRelation
	self deny: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 5/8/2005 20:31'!
false
	^ MAConstantRelation false.! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	^ relation! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
relation
	^ relation! !

!MARelationTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
relationInstance
	^ self testedClass new.! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:31'!
satisfies: aRelation
	self assert: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:31'!
setUp
	super setUp.
	relation := self relationInstance.! !

!MARelationTest methodsFor: 'private' stamp: 'lr 8/13/2005 11:55'!
testedClass
	^ MARelation! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 5/8/2005 20:31'!
true
	^ MAConstantRelation true.! !

MATestCase subclass: #MARelationParserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MARelationParserTest methodsFor: 'accessing' stamp: 'lr 6/2/2005 12:20'!
parser
	^ MARelationParser! !

!MATestCase class methodsFor: 'private' stamp: 'lr 5/8/2005 20:34'!
buildTestClassFor: aClass
	| thisName thisClass thisCategory parentClass |
	thisName := (aClass name , 'Test') asSymbol.
	thisClass := Smalltalk classNamed: thisName.
	thisCategory := 'Magritte-Tests-' , (aClass category copyAfterLast: $-).
	parentClass := self = thisClass
		ifTrue: [ self superclass ]
		ifFalse: [ Smalltalk classNamed: (aClass superclass name , 'Test') asSymbol ].
	(thisName beginsWith: 'MA') ifFalse: [ ^ self ].
	thisClass := parentClass 
		subclass: thisName
		instanceVariableNames: (thisClass isNil 
			ifFalse: [ thisClass instanceVariablesString ]
			ifTrue: [ String new ])
		classVariableNames: ''
		poolDictionaries: ''
		category: thisCategory.
	thisClass compile: 'testedClass
	^ ' , aClass name classified: #private.
	thisClass class compile: 'isAbstract
	^ ' , aClass isAbstract asString classified: #testing.
	aClass subclassesDo: [ :each | self buildTestClassFor: each ].! !

!MATestCase class methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:34'!
shouldInheritSelectors
	^ true! !

!MATestCase methodsFor: 'packages' stamp: 'lr 5/8/2005 20:33'!
classesDo: aBlock
	self package classes do: [ :class |
		(class includesBehavior: TestCase)
			ifFalse: [ aBlock value: class ] ].! !

!MATestCase methodsFor: 'packages' stamp: 'lr 5/8/2005 20:37'!
methodsDo: aBlock
	| category |
	self package methods do: [ :reference |
		(reference actualClass includesBehavior: TestCase) ifFalse: [
			category := reference actualClass organization 
				categoryOfElement: reference methodSymbol.
			(category isNil or: [ (category beginsWith: 'generated') not ])
				ifTrue: [ aBlock value: reference ] ] ].! !

!MATestCase methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:33'!
notifications
	notifications isNil
		ifTrue: [ self notifications: OrderedCollection new ].
	^ notifications.! !

!MATestCase methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:33'!
notifications: aCollection
	notifications := aCollection.! !

!MATestCase methodsFor: 'packages' stamp: 'lr 5/8/2005 20:33'!
package
	^ PackageInfo named: (self class category copyUpTo: $-).! !

!MATestCase methodsFor: 'running' stamp: 'lr 5/8/2005 20:33'!
performTest
	[ super performTest ]
		on: MANotification
		do: [ :notification |
			self notifications add: notification.
			notification resume ].! !

!MATestCase methodsFor: 'packages' stamp: 'lr 5/8/2005 20:33'!
selectorsDo: aBlock
	self methodsDo: [ :method |
		aBlock 
			value: method actualClass
			value: method methodSymbol ].! !

!MATestCase methodsFor: 'running' stamp: 'lr 5/8/2005 20:33'!
setUp
	super setUp.
	self notifications: OrderedCollection new.! !

!MATestCase methodsFor: 'packages' stamp: 'lr 5/8/2005 20:33'!
subclassesOf: aClass do: aBlock
	self classesDo: [ :class |
		(class includesBehavior: aClass)
			ifTrue: [ aBlock value: class ] ].! !
